@@ -2,12 +2,13 @@
 
 __author__ = """Yossi Mosbacher"""
 __email__ = "joe.mosbacher@gmail.com"
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 from .dispatchers import json_serializable, get_widget
 from .widgets import (
     PydanticModelEditor,
     PydanticModelEditorCard,
-    PydanticModelListEditor,
+    ItemListEditor,
+    ItemDictEditor,
 )
 from .pane import Pydantic
